## Functionality

- [x] sparse linear solve
- [ ] sparse eigen vals
- [ ] sparse determination
- [ ] non linear solve 
- [ ] ODE operator
- [ ] matrix partition

## Efficiency

- [ ] sparse matmul
  - [ ] cusparse backend
- [ ] sparse linear solve
  - [ ] cusparse backend
  - [ ] petsc backend
  - [ ] torch backend
    - [ ] superLU
    - [x] cg
    - [ ] cgs
    - [ ] bicg
    - [x] bicgstab
    - [ ] gmres
    - [ ] qmr
    - [ ] minres
    - [ ] lgmres
    - [ ] tfqmr
    - [ ] lsqr
    - [ ] lsmr
  - [ ] torch distributed backend
- [ ] sparse eigen vals
- [ ] sparse determination